@@ -1,4 +1,4 @@
-# Copyright (c) 2003 Hyriand. All rights reserved.
+# Copyright (c) 2003-2004 Hyriand. All rights reserved.
 #
 import gtk
 import gobject
@@ -13,7 +13,7 @@ from pynicotine.utils import _
 class ServerFrame(settings_glade.ServerFrame):
 	def __init__(self, encodings):
 		settings_glade.ServerFrame.__init__(self, gtk.FALSE)
-		self.Server.set_popdown_strings(["mail.slsknet.org:2240", "mail.slsknet.org:2241"])
+		self.Server.set_popdown_strings(["server.slsknet.org:2240"])
 		self.Encoding.set_popdown_strings(encodings)
 
 	def SetSettings(self, config):
@@ -169,6 +169,8 @@ class TransfersFrame(settings_glade.TransfersFrame):
 			self.FriendsOnly.set_active(transfers["friendsonly"])
 		if transfers["preferfriends"] is not None:
 			self.PreferFriends.set_active(transfers["preferfriends"])
+		if transfers["lock"] is not None:
+			self.LockIncoming.set_active(transfers["lock"])
 		
 		self.OnQueueUseSlotsToggled(self.QueueUseSlots)
 		self.OnLimitToggled(self.Limit)
@@ -207,6 +209,7 @@ class TransfersFrame(settings_glade.TransfersFrame):
 				"friendsnolimits": self.FriendsNoLimits.get_active(),
 				"friendsonly": self.FriendsOnly.get_active(),
 				"preferfriends": self.PreferFriends.get_active(),
+				"lock": self.LockIncoming.get_active(),
 			},
 		}
 
@@ -411,6 +414,8 @@ class BloatFrame(settings_glade.BloatFrame):
 			self.Queue.set_text(ui["searchq"])
 		if ui["decimalsep"] is not None:
 			self.DecimalSep.entry.set_text(ui["decimalsep"])
+		if ui["tabclosers"] is not None:
+			self.TabClosers.set_active(ui["tabclosers"])
 
 	def GetSettings(self):
 		return {
@@ -422,6 +427,7 @@ class BloatFrame(settings_glade.BloatFrame):
 				"search": self.Immediate.get_text(),
 				"searchq": self.Queue.get_text(),
 				"decimalsep": self.DecimalSep.entry.get_text(),
+				"tabclosers": self.TabClosers.get_active(),
 			},
 		}
 	
@@ -448,6 +454,8 @@ class LogFrame(settings_glade.LogFrame):
 			self.LogPrivate.set_active(logging["privatechat"])
 		if logging["chatrooms"] is not None:
 			self.LogRooms.set_active(logging["chatrooms"])
+		if logging["transfers"] is not None:
+			self.LogTransfers.set_active(logging["transfers"])
 		if logging["logsdir"] is not None:
 			self.LogDir.set_text(recode(logging["logsdir"]))
 
@@ -457,6 +465,7 @@ class LogFrame(settings_glade.LogFrame):
 				"privatechat": self.LogPrivate.get_active(),
 				"chatrooms": self.LogRooms.get_active(),
 				"logsdir": recode2(self.LogDir.get_text()),
+				"transfers": self.LogTransfers.get_active(),
 			}
 		}
 
@@ -487,6 +496,8 @@ class SearchFrame(settings_glade.SearchFrame):
 			self.FilterSize.set_text(searches["defilter"][2])
 			self.FilterBR.set_text(searches["defilter"][3])
 			self.FilterFree.set_active(searches["defilter"][4])
+			if(len(searches["defilter"]) > 5):
+				self.FilterCC.set_text(searches["defilter"][5])
 
 	def GetSettings(self):
 		maxresults = int(self.MaxResults.get_text())
@@ -501,6 +512,7 @@ class SearchFrame(settings_glade.SearchFrame):
 					self.FilterSize.get_text(),
 					self.FilterBR.get_text(),
 					self.FilterFree.get_active(),
+					self.FilterCC.get_text(),
 				],
 			}
 		}
