@@ -1,4 +1,4 @@
-# Copyright (c) 2003 Hyriand. All rights reserved.
+# Copyright (c) 2003-2004 Hyriand. All rights reserved.
 #
 # Based on code from PySoulSeek, original copyright note:
 # Copyright (c) 2001-2003 Alexander Kanavin. All rights reserved.
@@ -126,7 +126,7 @@ class Notify(InternalMessage):
 class SlskMessage:
     """ This is a parent class for all protocol messages. """
 
-    def getObject(self,message,type, start=0, getintasshort=0):
+    def getObject(self,message,type, start=0, getintasshort=0, getsignedint=0):
 	""" Returns object of specified type, extracted from message (which is
 	a binary array). start is an offset."""
         intsize = struct.calcsize("<I")
@@ -134,6 +134,8 @@ class SlskMessage:
             if type is types.IntType:
                 if getintasshort:
                     return intsize+start,struct.unpack("<H",message[start:start+struct.calcsize("<H")])[0]
+                elif getsignedint:
+                    return intsize+start,struct.unpack("<i",message[start:start+intsize])[0]
                 else:
                     return intsize+start,struct.unpack("<I",message[start:start+intsize])[0]
             elif type is types.LongType:
@@ -320,7 +322,8 @@ class JoinRoom(ServerMessage):
 #	len, something = self.getObject(message, types.StringType, len)
         len, statslen = self.getObject(message,types.IntType,len)
         for i in range(statslen):
-            len, users[i][2] = self.getObject(message,types.IntType,len)
+            len, users[i][2] = self.getObject(message,types.IntType,len,getsignedint=1)
+#            len, users[i][2] = self.getObject(message,types.IntType,len)
             len, users[i][3] = self.getObject(message,types.IntType,len)
             len, users[i][4] = self.getObject(message,types.IntType,len)
             len, users[i][5] = self.getObject(message,types.IntType,len)
@@ -352,7 +355,9 @@ class UserJoinedRoom(ServerMessage):
         len,self.room = self.getObject(message,types.StringType)
         len,self.username = self.getObject(message,types.StringType,len)
 	i = [None,None,None,None,None,None,None]
-	for j in range(7):
+	len, i[0] = self.getObject(message,types.IntType,len)
+	len, i[1] = self.getObject(message,types.IntType,len,getsignedint=1)
+	for j in range(2,7):
 	    len, i[j] =(self.getObject(message,types.IntType,len))
 	self.userdata = UserData(i)
 
@@ -362,6 +367,51 @@ class UserLeftRoom(ServerMessage):
         len,self.room = self.getObject(message,types.StringType)
         len,self.username = self.getObject(message,types.StringType,len)
 
+class RoomTickerState(ServerMessage):
+    def __init__(self):
+       self.room = None
+       self.user = None
+       self.msgs = {}
+
+    def parseNetworkMessage(self,message):
+        len,self.room = self.getObject(message,types.StringType)
+        len,n = self.getObject(message,types.IntType,len)
+        for i in range(n):
+            len,user = self.getObject(message,types.StringType, len)
+            len,msg = self.getObject(message,types.StringType, len)
+            self.msgs[user] = msg
+
+class RoomTickerAdd(ServerMessage):
+    def __init__(self):
+       self.room = None
+       self.user = None
+       self.msg = None
+
+    def parseNetworkMessage(self,message):
+       len,self.room = self.getObject(message,types.StringType)
+       len,self.user = self.getObject(message,types.StringType,len)
+       len,self.msg = self.getObject(message,types.StringType,len)
+
+class RoomTickerRemove(ServerMessage):
+    def __init__(self, room = None):
+        self.user = None
+        self.room = room
+
+    def parseNetworkMessage(self,message):
+        len,self.room = self.getObject(message,types.StringType)
+        len,self.user = self.getObject(message,types.StringType, len)
+
+class RoomTickerSet(ServerMessage):
+    def __init__(self, room = None, msg = None):
+        self.room = room
+        if not msg:
+            self.msg = ""
+        else:
+            self.msg = msg
+
+    def makeNetworkMessage(self):
+        return self.packObject(self.room) + self.packObject(self.msg)
+
 class ConnectToPeer(ServerMessage):
     """ Either we ask server to tell someone else we want to establish a 
     connection with him or server tells us someone wants to connect with us.
@@ -413,16 +463,16 @@ class FileSearch(ServerMessage):
     """ We send this to the server when we search for something."""
     """ Server send this to tell us someone is searching for something."""
     def __init__(self, requestid = None, text = None):
-        self.requestid = requestid
-        self.text = text
+        self.searchid = requestid
+        self.searchterm = text
 
     def makeNetworkMessage(self):
-        return self.packObject(self.requestid)+self.packObject(self.text)
+        return self.packObject(self.searchid)+self.packObject(self.searchterm)
 
     def parseNetworkMessage(self,message):
         len, self.user = self.getObject(message,types.StringType)
-        len, self.requestid = self.getObject(message,types.IntType, len)
-        len, self.search = self.getObject(message,types.StringType, len)
+        len, self.searchid = self.getObject(message,types.IntType, len)
+        len, self.searchterm = self.getObject(message,types.StringType, len)
 
 class WishlistSearch(FileSearch):
     pass
@@ -464,7 +514,7 @@ class GetUserStats(ServerMessage):
 
     def parseNetworkMessage(self, message):
 	len, self.user = self.getObject(message,types.StringType)
-        len, self.avgspeed = self.getObject(message,types.IntType, len)
+        len, self.avgspeed = self.getObject(message,types.IntType, len, getsignedint = 1)
         len, self.downloadnum = self.getObject(message,types.IntType, len)
         len, self.something = self.getObject(message,types.IntType, len)
         len, self.files = self.getObject(message,types.IntType, len)
@@ -670,6 +720,9 @@ class AddThingILike(ServerMessage):
     def makeNetworkMessage(self):
         return self.packObject(self.thing)
 
+class AddThingIHate(AddThingILike):
+    pass
+
 class RemoveThingILike(ServerMessage):
     """ Remove item from our likes list """
     def __init__(self, thing = None):
@@ -678,6 +731,9 @@ class RemoveThingILike(ServerMessage):
     def makeNetworkMessage(self):
         return self.packObject(self.thing)
 
+class RemoveThingIHate(RemoveThingILike):
+    pass
+
 class GlobalRecommendations(ServerMessage):
     def __init__(self):
         self.recommendations = None
@@ -952,9 +1008,9 @@ class FileSearchResult(PeerMessage):
             list.append([code,name,size,ext,attrs])
         self.list = list
 	len, self.freeulslots = len+1, ord(message[len])
-	len, self.ulspeed = self.getObject(message,types.IntType, len)
+	len, self.ulspeed = self.getObject(message,types.IntType, len, getsignedint=1)
 	len, self.inqueue = self.getObject(message,types.IntType, len)
-
+        
     def makeNetworkMessage(self):
 	filelist = []
 	for i in self.list:
