@@ -1,4 +1,4 @@
-# Copyright (c) 2003 Hyriand. All rights reserved.
+# Copyright (c) 2003-2004 Hyriand. All rights reserved.
 #
 # Based on code from PySoulSeek, original copyright note:
 # Copyright (c) 2001-2003 Alexander Kanavin. All rights reserved.
@@ -171,6 +171,7 @@ class NetworkEventProcessor:
 			slskmessages.PlaceholdUpload:self.PlaceholdUpload,
 			slskmessages.PlaceInQueueRequest:self.PlaceInQueueRequest,
 			slskmessages.SearchRequest:self.SearchRequest,
+			slskmessages.FileSearch:self.SearchRequest,
 			slskmessages.NetInfo:self.NetInfo,
 			slskmessages.DistribAlive:self.DistribAlive,
 			slskmessages.DistribSearch:self.DistribSearch,
@@ -183,6 +184,9 @@ class NetworkEventProcessor:
 			slskmessages.ItemRecommendations:self.ItemRecommendations,
 			slskmessages.SimilarUsers:self.SimilarUsers,
 			slskmessages.ItemSimilarUsers:self.ItemSimilarUsers,
+			slskmessages.RoomTickerState:self.RoomTickerState,
+			slskmessages.RoomTickerAdd:self.RoomTickerAdd,
+			slskmessages.RoomTickerRemove:self.RoomTickerRemove,
 #			slskmessages.PrivilegedUsersZ:self.PrivilegedUsers,
 			}
 
@@ -411,6 +415,8 @@ class NetworkEventProcessor:
 	    self.queue.put(slskmessages.SetStatus((not self.frame.away)+1))
 	    for thing in self.config.sections["interests"]["likes"]:
                 self.queue.put(slskmessages.AddThingILike(self.encode(thing)))
+	    for thing in self.config.sections["interests"]["dislikes"]:
+                self.queue.put(slskmessages.AddThingIHate(self.encode(thing)))
 	else:
 	    self.frame.manualdisconnect = 1
 	    self.setStatus(_("Can not log in, reason: %s") %(msg.reason))
@@ -434,6 +440,16 @@ class NetworkEventProcessor:
     def JoinRoom(self,msg):
 	if self.chatrooms is not None:
             self.chatrooms.roomsctrl.JoinRoom(msg)
+            ticker = ""
+            if self.config.sections["ticker"]["rooms"].has_key(msg.room):
+                ticker = self.config.sections["ticker"]["rooms"][msg.room]
+            elif self.config.sections["ticker"]["default"]:
+                ticker = self.config.sections["ticker"]["default"]
+            if ticker:
+                encoding = self.config.sections["server"]["enc"]
+                if self.config.sections["server"]["roomencoding"].has_key(msg.room):
+                  encoding = self.config.sections["server"]["roomencoding"][msg.room]
+                self.queue.put(slskmessages.RoomTickerSet(msg.room, self.encode(ticker, encoding)))
         else:
             self.logMessage("%s %s" %(msg.__class__, vars(msg)))
 
@@ -473,7 +489,10 @@ class NetworkEventProcessor:
             self.logMessage("%s %s" %(msg.__class__, vars(msg)))
 
     def CheckPrivileges(self, msg):
-	self.logMessage(_("%i seconds of download privileges left") %(msg.days))
+        mins = msg.days / 60
+        hours = mins / 60
+        days = hours / 24
+	self.logMessage(_("%i days, %i hours, %i minutes, %i seconds of download privileges left") %(days, hours % 24, mins % 60, msg.days % 60))
 
     def AdminMessage(self, msg):
 	self.logMessage("%s" %(msg.msg))
@@ -682,7 +701,14 @@ class NetworkEventProcessor:
     def FileSearchResult(self, msg):
 	for i in self.peerconns:
 	    if i.conn is msg.conn.conn and self.search is not None:
-		self.search.ShowResult(msg, i.username)
+	        if self.geoip:
+	          if i.addr:
+	            country = self.geoip.country_code_by_addr(i.addr[0])
+	          else:
+	            country = ""
+	        else:
+	          country = ""
+		self.search.ShowResult(msg, i.username, country)
 
     def PierceFireWall(self, msg):
 	for i in self.peerconns:
@@ -961,6 +987,37 @@ class NetworkEventProcessor:
     def ItemSimilarUsers(self, msg):
         self.frame.ItemSimilarUsers(msg)
 
+    def RoomTickerState(self, msg):
+        if self.chatrooms is not None:
+            self.chatrooms.roomsctrl.TickerSet(msg)
+        else:
+            self.logMessage("%s %s" %(msg.__class__, vars(msg)))
+    
+    def RoomTickerAdd(self, msg):
+        if self.chatrooms is not None:
+            self.chatrooms.roomsctrl.TickerAdd(msg)
+        else:
+            self.logMessage("%s %s" %(msg.__class__, vars(msg)))
+    
+    def RoomTickerRemove(self, msg):
+        if self.chatrooms is not None:
+            self.chatrooms.roomsctrl.TickerRemove(msg)
+        else:
+            self.logMessage("%s %s" %(msg.__class__, vars(msg)))
+
+    def logTransfer(self, message, toUI = 0):
+        if self.config.sections["logging"]["transfers"]:
+            fn = os.path.join(self.config.sections["logging"]["logsdir"], "transfers.log")
+            try:
+                f = open(fn, "a")
+                f.write(time.strftime("%c"))
+                f.write(" %s\n" % message)
+                f.close()
+            except IOError, error:
+                self.logMessage("Couldn't write to transfer log: %s" % error)
+        if toUI:
+	        self.logMessage(message)
+        
 class UserAddr:
     def __init__(self, addr = None, behindfw = None, status = None):
 	self.addr = addr
