@@ -1,4 +1,4 @@
-# Copyright (c) 2003 Hyriand. All rights reserved.
+# Copyright (c) 2003-2004 Hyriand. All rights reserved.
 #
 # Based on code from PySoulSeek, original copyright note:
 # Copyright (c) 2001-2003 Alexander Kanavin. All rights reserved.
@@ -91,7 +91,10 @@ class SlskProtoThread(threading.Thread):
 		   HaveNoParent:71,SearchRequest:93,NetInfo:102,
 		   WishlistSearch:103,WishlistInterval:104,
 		   SimilarUsers:110,ItemRecommendations:111,
-                   ItemSimilarUsers:112,PrivilegedUsersZ:120}
+                   ItemSimilarUsers:112,RoomTickerState:113,
+                   RoomTickerAdd:114,RoomTickerRemove:115,
+                   RoomTickerSet:116,AddThingIHate:117,RemoveThingIHate:118,
+                   PrivilegedUsersZ:120}
     peercodes = {GetSharedFileList:4, SharedFileList:5, FileSearchRequest:8,
 		FileSearchResult:9,
 		UserInfoRequest:15,UserInfoReply:16, FolderContentsRequest:36,
