@@ -1,4 +1,4 @@
-# Copyright (c) 2003 Hyriand. All rights reserved.
+# Copyright (c) 2003-2004 Hyriand. All rights reserved.
 #
 import gtk
 import gobject
@@ -8,6 +8,7 @@ from pynicotine import slskmessages
 from nicotine_glade import ChatRoomTab
 from utils import InitialiseColumns, AppendLine, PopupMenu, FastListModel, string_sort_func, WriteLog, int_sort_func, Humanize, expand_alias, EncodingsMenu, SaveEncoding
 from pynicotine.utils import _
+from ticker import Ticker
 
 def GetCompletion(part, list):
 	matches = []
@@ -82,7 +83,7 @@ class RoomsControl:
 			( "", None ),
 			( _("Refresh"), self.OnPopupRefresh ),
 		)
-		frame.roomlist.RoomsList.connect("button_press_event", self.OnPopupMenu)
+		frame.roomlist.RoomsList.connect("button_press_event", self.OnListClicked)
 		frame.roomlist.RoomsList.set_headers_clickable(gtk.TRUE)
 		
 		self.frame.ChatNotebook.connect("switch-page", self.OnSwitchPage)
@@ -114,6 +115,21 @@ class RoomsControl:
 		self.roomsmodel.sort_col = column_id
 		self.OnResort(column, column_id)
 		
+	def OnListClicked(self, widget, event):
+		if self.roomsmodel is None:
+			return gtk.FALSE
+		if event.button == 1 and event.type == gtk.gdk._2BUTTON_PRESS:
+			d = self.frame.roomlist.RoomsList.get_path_at_pos(int(event.x), int(event.y))
+			if d:
+				path, column, x, y = d
+				room = self.roomsmodel.get_value(self.roomsmodel.get_iter(path), 0)
+				if not room in self.joinedrooms.keys():
+					self.frame.np.queue.put(slskmessages.JoinRoom(room))
+			return gtk.TRUE
+		elif event.button == 3:
+			return self.OnPopupMenu(widget, event)
+		return gtk.FALSE
+		
 	def OnPopupMenu(self, widget, event):
 		if event.button != 3 or self.roomsmodel is None:
 			return
@@ -180,6 +196,15 @@ class RoomsControl:
 	def UserLeftRoom(self, msg):
 		self.joinedrooms[msg.room].UserLeftRoom(msg.username)
 	
+	def TickerSet(self, msg):
+		self.joinedrooms[msg.room].TickerSet(msg)
+
+	def TickerAdd(self, msg):
+		self.joinedrooms[msg.room].TickerAdd(msg)
+
+	def TickerRemove(self, msg):
+		self.joinedrooms[msg.room].TickerRemove(msg)
+
 	def SayChatRoom(self, msg, text):
 		if msg.user in self.frame.np.config.sections["server"]["ignorelist"]:
 			return
@@ -205,6 +230,57 @@ class RoomsControl:
 			room.ConnClose()
 		self.autojoin = 1
 
+def TickDialog(parent, default = ""):
+	dlg = gtk.Dialog(title = _("Set ticker message"), parent = parent,
+		buttons = (gtk.STOCK_OK, gtk.RESPONSE_OK, gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))
+	dlg.set_default_response(gtk.RESPONSE_OK)
+	
+	t = 0
+	
+	dlg.set_border_width(10)
+	dlg.vbox.set_spacing(10)
+		
+	l = gtk.Label(_("Set room ticker message:"))
+	l.set_alignment(0, 0.5)
+	dlg.vbox.pack_start(l, gtk.FALSE, gtk.FALSE)
+	
+	entry = gtk.Entry()
+	entry.set_activates_default(gtk.TRUE)
+	entry.set_text(default)
+	dlg.vbox.pack_start(entry, gtk.TRUE, gtk.TRUE)
+
+	h = gtk.HBox(gtk.FALSE, gtk.FALSE)
+	r1 = gtk.RadioButton()
+	r1.set_label(_("Just this time"))
+	r1.set_active(gtk.TRUE)
+	h.pack_start(r1, gtk.FALSE, gtk.FALSE)
+	
+	r2 = gtk.RadioButton(r1)
+	r2.set_label(_("Always for this channel"))
+	h.pack_start(r2, gtk.FALSE, gtk.FALSE)
+	
+	r3 = gtk.RadioButton(r1)
+	r3.set_label(_("Default for all channels"))
+	h.pack_start(r3, gtk.FALSE, gtk.FALSE)
+	
+	dlg.vbox.pack_start(h, gtk.TRUE, gtk.TRUE)
+	
+	dlg.vbox.show_all()
+
+	result = None
+	if dlg.run() == gtk.RESPONSE_OK:
+		if r1.get_active():
+			t = 0
+		elif r2.get_active():
+			t = 1
+		elif r3.get_active():
+			t = 2
+		result = entry.get_text()
+		
+	dlg.destroy()
+		
+	return [t, result]
+
 class ChatRoom(ChatRoomTab):
 	def __init__(self, roomsctrl, room, users):
 		ChatRoomTab.__init__(self, gtk.FALSE)
@@ -216,6 +292,9 @@ class ChatRoom(ChatRoomTab):
 		self.logfile = None
 		self.leaving = 0
 
+		if not self.frame.np.config.sections["ticker"]["hide"]:
+			self.Ticker.show()
+
 		if self.frame.translux:
 			self.tlux_roomlog = lambda: self.RoomLog.get_window(gtk.TEXT_WINDOW_TEXT)
 			self.tlux_chat = lambda: self.ChatScroll.get_window(gtk.TEXT_WINDOW_TEXT)
@@ -280,6 +359,13 @@ class ChatRoom(ChatRoomTab):
 		self.logpopupmenu = PopupMenu(self.frame).setup(["Clear log", self.OnClearRoomLog])
 		self.RoomLog.connect("button-press-event", self.OnPopupRoomLogMenu)
 		
+	def get_custom_widget(self, id, string1, string2, int1, int2):
+		if id == "Ticker":
+			t = Ticker()
+			return t
+		else:
+			return ChatRoomTab.get_custom_widget(self, id, string1, string2, int1, int2)
+			
 	def destroy(self):
 		if self.frame.translux:
 			self.frame.translux.unsubscribe(self.tlux_roomlog)
@@ -301,6 +387,18 @@ class ChatRoom(ChatRoomTab):
 		items[7].set_active(user in self.frame.np.config.sections["server"]["ignorelist"])
 		self.popup_menu.popup(None, None, None, event.button, event.time)
 		
+	def TickerSet(self, msg):
+		self.Ticker.set_ticker({})
+		for m in msg.msgs.keys():
+			self.Ticker.add_ticker(m, self.frame.np.decode(msg.msgs[m], self.encoding))
+
+	def TickerAdd(self, msg):
+		text = self.frame.np.decode(msg.msg, self.encoding)
+		self.Ticker.add_ticker(msg.user, text)
+
+	def TickerRemove(self, msg):
+		self.Ticker.remove_ticker(msg.user)
+		
 	def SayChatRoom(self, msg, text):
 		login = self.frame.np.config.sections["server"]["login"]
 		if msg.user == login:
@@ -338,7 +436,7 @@ class ChatRoom(ChatRoomTab):
 	
 	CMDS = ["/alias ", "/unalias ", "/whois ", "/browse ", "/ip ", "/pm ", "/msg ", "/search ", "/usearch ", "/rsearch ",
 		"/bsearch ", "/join ", "/leave", "/add ", "/ban ", "/ignore ", "/unban ", "/unignore ", "/clear", "/part ", "/quit",
-		"/rescan"]
+		"/rescan", "/tick"]
 
 	def OnEnter(self, widget):
 		text = self.frame.np.encode(widget.get_text(), self.encoding)
@@ -366,6 +464,11 @@ class ChatRoom(ChatRoomTab):
 		elif cmd in ["/b", "/browse"]:
 			if args:
 				self.frame.BrowseUser(args)
+		elif cmd == "/nsa":
+			if args:
+#				self.frame.np.queue.put(slskmessages.GetPeerAddress(args))
+				self.frame.np.ProcessRequestToPeer(args, slskmessages.UserInfoRequest(None), self.frame.userinfo)
+				self.frame.BrowseUser(args)
 		elif cmd == "/ip":
 			if args:
 				self.frame.np.queue.put(slskmessages.GetPeerAddress(args))
@@ -426,8 +529,8 @@ class ChatRoom(ChatRoomTab):
 			self.frame.OnExit(None)
 		elif cmd == "/rescan":
 			self.frame.OnRescan()
-		elif cmd == "/bug":
-			samplebug
+		elif cmd  in ["/tick", "/t"]:
+			self.frame.np.queue.put(slskmessages.RoomTickerSet(self.room, self.frame.np.encode(args, self.encoding)))
 		elif cmd and cmd[:1] == "/" and cmd != "/me" and cmd[:2] != "//":
 			self.frame.logMessage(_("Command %s is not recognized") % text)
 			return
@@ -570,6 +673,38 @@ class ChatRoom(ChatRoomTab):
 	def OnClearRoomLog(self, widget):
 		self.RoomLog.get_buffer().set_text("")
 
+	def OnTickerClicked(self, widget, event):
+		if event.button != 1:
+			return gtk.FALSE
+		if self.Ticker.messages.has_key(self.frame.np.config.sections["server"]["login"]):
+			old = self.Ticker.messages[self.frame.np.config.sections["server"]["login"]]
+		else:
+			old = ""
+		t, result = TickDialog(self.frame.MainWindow, old)
+		if not result is None:
+			if t == 1:
+				if not result:
+					if self.frame.np.config.sections["ticker"]["rooms"].has_key(self.room):
+						del self.frame.np.config.sections["ticker"]["rooms"][self.room]
+				else:
+					self.frame.np.config.sections["ticker"]["rooms"][self.room] = result
+				self.frame.np.config.writeConfig()
+			elif t == 2:
+				if self.frame.np.config.sections["ticker"]["rooms"].has_key(self.room):
+					del self.frame.np.config.sections["ticker"]["rooms"][self.room]
+				self.frame.np.config.sections["ticker"]["default"] = result
+				self.frame.np.config.writeConfig()
+			self.frame.np.queue.put(slskmessages.RoomTickerSet(self.room, self.frame.np.encode(result, self.encoding)))
+		return gtk.TRUE
+
+	def ShowTicker(self, visible):
+		if visible:
+			self.Ticker.enable()
+			self.Ticker.show()
+		else:
+			self.Ticker.disable()
+			self.Ticker.hide()
+
 class ChatRooms:
 	def __init__(self, frame):
 		frame.ChatNotebook.popup_enable()
