@@ -1,4 +1,4 @@
-# Copyright (c) 2003 Hyriand. All rights reserved.
+# Copyright (c) 2003-2004 Hyriand. All rights reserved.
 #
 import os
 
@@ -156,7 +156,7 @@ class testwin(MainWindow):
 
 		self.MainWindow.connect("destroy", self.OnDestroy)
 		self.MainWindow.connect("key_press_event", self.OnKeyPress)
-		self.MainWindow.connect("motion_notify_event", self.OnButtonPress)
+		self.MainWindow.connect("motion-notify-event", self.OnButtonPress)
 		
 		gobject.signal_new("network_event", gtk.Window, gobject.SIGNAL_RUN_FIRST, gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT,))
 		gobject.signal_new("network_event_lo", gtk.Window, gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT,))
@@ -214,6 +214,9 @@ class testwin(MainWindow):
 			self.hpaned1.pack2(self.roomlist.vbox2, gtk.FALSE, gtk.TRUE)
 			self.hide_room_list1.set_active(0)
 
+		if self.np.config.sections["ticker"]["hide"]:
+			self.hide_tickers1.set_active(1)
+
 		self.settingswindow = SettingsWindow(self)
 		self.settingswindow.SettingsWindow.connect("settings-closed", self.OnSettingsClosed)
 		
@@ -740,14 +743,13 @@ class testwin(MainWindow):
 			self.np.config.sections["interests"]["dislikes"].append(thing)
 			self.dislikes[thing] = self.dislikeslist.append([thing])
 			self.np.config.writeConfig()
+			self.np.queue.put(slskmessages.AddThingIHate(self.np.encode(thing)))
 
 	def SetRecommendations(self, title, recom):
 		self.recommendationslist.clear()
 		for thing in recom.keys():
 			rating = recom[thing]
 			thing = self.np.decode(thing)
-			if thing in self.np.config.sections["interests"]["dislikes"]:
-				continue
 			self.recommendationslist.append([thing, Humanize(rating), rating])
 		self.recommendationslist.set_sort_column_id(2, gtk.SORT_DESCENDING)
 
@@ -850,6 +852,7 @@ class testwin(MainWindow):
 		del self.dislikes[thing]
 		self.np.config.sections["interests"]["dislikes"].remove(thing)
 		self.np.config.writeConfig()
+		self.np.queue.put(slskmessages.RemoveThingIHate(self.np.encode(thing)))
 	
 	def OnPopupTIDLMenu(self, widget, event):
 		if event.button != 3:
@@ -883,11 +886,13 @@ class testwin(MainWindow):
 			self.np.config.sections["interests"]["dislikes"].append(thing)
 			self.dislikes[thing] = self.dislikeslist.append([thing])
 			self.np.config.writeConfig()
+			self.np.queue.put(slskmessages.AddThingIHate(self.np.encode(thing)))
 		elif not widget.get_active() and thing in self.np.config.sections["interests"]["dislikes"]:
 			self.dislikeslist.remove(self.dislikes[thing])
 			del self.dislikes[thing]
 			self.np.config.sections["interests"]["dislikes"].remove(thing)
 			self.np.config.writeConfig()
+			self.np.queue.put(slskmessages.RemoveThingIHate(self.np.encode(thing)))
 
 	def OnRecommendRecommendation(self, widget):
 		thing = self.r_popup_menu.get_user()
@@ -914,6 +919,15 @@ class testwin(MainWindow):
 		items[1].set_active(thing in self.np.config.sections["interests"]["dislikes"])
 		self.r_popup_menu.popup(None, None, None, event.button, event.time)
 
+	def OnHideTickers(self, widget):
+		if not self.chatrooms:
+			return
+		hide = widget.get_active()
+		self.np.config.sections["ticker"]["hide"] = hide
+		self.np.config.writeConfig()
+		for room in self.chatrooms.roomsctrl.joinedrooms.values():
+			room.ShowTicker(not hide)
+
 class MainApp:
 	def __init__(self, config):
 		self.frame = testwin(config)
