@@ -63,6 +63,7 @@ class MainWindow:
         self.file1_menu.append(self.scheidingslijn1)
 
         self.show_debug_info1 = gtk.CheckMenuItem(_("Show debug info"))
+        self.show_debug_info1.set_active(gtk.FALSE)
         self.show_debug_info1.show()
         self.show_debug_info1.connect("activate", self.OnShowDebug)
 
@@ -74,6 +75,7 @@ class MainWindow:
         self.file1_menu.append(self.scheidingslijn8)
 
         self.hide_log_window1 = gtk.CheckMenuItem(_("Hide log window"))
+        self.hide_log_window1.set_active(gtk.FALSE)
         self.hide_log_window1.show()
         self.hide_log_window1.connect("activate", self.OnHideLog)
         self.hide_log_window1.add_accelerator("activate", self.accel_group, gtk.gdk.keyval_from_name("h"), gtk.gdk.MOD1_MASK, gtk.ACCEL_VISIBLE)
@@ -81,12 +83,21 @@ class MainWindow:
         self.file1_menu.append(self.hide_log_window1)
 
         self.hide_room_list1 = gtk.CheckMenuItem(_("Hide room list"))
+        self.hide_room_list1.set_active(gtk.FALSE)
         self.hide_room_list1.show()
         self.hide_room_list1.connect("activate", self.OnHideRoomList)
         self.hide_room_list1.add_accelerator("activate", self.accel_group, gtk.gdk.keyval_from_name("r"), gtk.gdk.MOD1_MASK, gtk.ACCEL_VISIBLE)
 
         self.file1_menu.append(self.hide_room_list1)
 
+        self.hide_tickers1 = gtk.CheckMenuItem(_("Hide tickers"))
+        self.hide_tickers1.set_active(gtk.FALSE)
+        self.hide_tickers1.show()
+        self.hide_tickers1.connect("activate", self.OnHideTickers)
+        self.hide_tickers1.add_accelerator("activate", self.accel_group, gtk.gdk.keyval_from_name("t"), gtk.gdk.MOD1_MASK, gtk.ACCEL_VISIBLE)
+
+        self.file1_menu.append(self.hide_tickers1)
+
         self.scheidingslijn5 = gtk.MenuItem()
         self.scheidingslijn5.show()
 
@@ -270,18 +281,21 @@ class MainWindow:
         self.hbox2.pack_start(self.combo1, gtk.TRUE, gtk.TRUE, 0)
 
         self.GlobalRadio = gtk.RadioButton()
+        self.GlobalRadio.set_active(gtk.FALSE)
         self.GlobalRadio.set_label(_("Global"))
         self.GlobalRadio.show()
 
         self.hbox2.pack_start(self.GlobalRadio, gtk.FALSE, gtk.FALSE, 0)
 
         self.RoomsRadio = gtk.RadioButton(self.GlobalRadio)
+        self.RoomsRadio.set_active(gtk.FALSE)
         self.RoomsRadio.set_label(_("Rooms"))
         self.RoomsRadio.show()
 
         self.hbox2.pack_start(self.RoomsRadio, gtk.FALSE, gtk.FALSE, 0)
 
         self.BuddiesRadio = gtk.RadioButton(self.GlobalRadio)
+        self.BuddiesRadio.set_active(gtk.FALSE)
         self.BuddiesRadio.set_label(_("Buddies"))
         self.BuddiesRadio.show()
 
@@ -370,10 +384,32 @@ class MainWindow:
 
         self.vbox14.pack_start(self.scrolledwindow23, gtk.TRUE, gtk.TRUE, 0)
 
-        self.button15 = gtk.Button(None, gtk.STOCK_ADD)
+        self.button15 = gtk.Button()
         self.button15.show()
         self.button15.connect("clicked", self.OnAddThingILike)
 
+        self.alignment2 = gtk.Alignment(0.5, 0.5, 0, 0)
+        self.alignment2.show()
+
+        self.hbox15 = gtk.HBox(gtk.FALSE, 2)
+        self.hbox15.show()
+        self.hbox15.set_spacing(2)
+
+        self.image2 = gtk.Image()
+        self.image2.set_padding(0, 0)
+        self.image2.set_from_stock(gtk.STOCK_ADD, 4)
+        self.image2.show()
+        self.hbox15.pack_start(self.image2, gtk.FALSE, gtk.FALSE, 0)
+
+        self.label22 = gtk.Label(_("Add"))
+        self.label22.set_padding(0, 0)
+        self.label22.show()
+        self.hbox15.pack_start(self.label22, gtk.FALSE, gtk.FALSE, 0)
+
+        self.alignment2.add(self.hbox15)
+
+        self.button15.add(self.alignment2)
+
         self.vbox14.pack_start(self.button15, gtk.FALSE, gtk.FALSE, 0)
 
         self.vbox13.pack_start(self.vbox14, gtk.TRUE, gtk.TRUE, 0)
@@ -394,10 +430,32 @@ class MainWindow:
 
         self.vbox15.pack_start(self.scrolledwindow24, gtk.TRUE, gtk.TRUE, 0)
 
-        self.button16 = gtk.Button(None, gtk.STOCK_ADD)
+        self.button16 = gtk.Button()
         self.button16.show()
         self.button16.connect("clicked", self.OnAddThingIDislike)
 
+        self.alignment1 = gtk.Alignment(0.5, 0.5, 0, 0)
+        self.alignment1.show()
+
+        self.hbox14 = gtk.HBox(gtk.FALSE, 2)
+        self.hbox14.show()
+        self.hbox14.set_spacing(2)
+
+        self.image1 = gtk.Image()
+        self.image1.set_padding(0, 0)
+        self.image1.set_from_stock(gtk.STOCK_ADD, 4)
+        self.image1.show()
+        self.hbox14.pack_start(self.image1, gtk.FALSE, gtk.FALSE, 0)
+
+        self.label21 = gtk.Label(_("Add"))
+        self.label21.set_padding(0, 0)
+        self.label21.show()
+        self.hbox14.pack_start(self.label21, gtk.FALSE, gtk.FALSE, 0)
+
+        self.alignment1.add(self.hbox14)
+
+        self.button16.add(self.alignment1)
+
         self.vbox15.pack_start(self.button16, gtk.FALSE, gtk.FALSE, 0)
 
         self.vbox13.pack_start(self.vbox15, gtk.TRUE, gtk.TRUE, 0)
@@ -566,6 +624,9 @@ class MainWindow:
     def OnHideRoomList(self, widget):
         pass
 
+    def OnHideTickers(self, widget):
+        pass
+
     def OnSettings(self, widget):
         pass
 
@@ -658,6 +719,10 @@ class ChatRoomTab:
         self.vbox6.show()
         self.vbox6.set_spacing(0)
 
+        self.Ticker = self.get_custom_widget("Ticker", "", "", 0, 0)
+        self.Ticker.connect("button_press_event", self.OnTickerClicked)
+        self.vbox6.pack_start(self.Ticker, gtk.FALSE, gtk.TRUE, 0)
+
         self.scrolledwindow15 = gtk.ScrolledWindow()
         self.scrolledwindow15.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.scrolledwindow15.show()
@@ -711,12 +776,14 @@ class ChatRoomTab:
         self.hbox4.set_spacing(0)
 
         self.Log = gtk.CheckButton()
+        self.Log.set_active(gtk.FALSE)
         self.Log.set_label(_("Log"))
         self.Log.show()
         self.Log.connect("toggled", self.OnLogToggled)
         self.hbox4.pack_start(self.Log, gtk.FALSE, gtk.FALSE, 0)
 
         self.AutoJoin = gtk.CheckButton()
+        self.AutoJoin.set_active(gtk.FALSE)
         self.AutoJoin.set_label(_("Auto-join"))
         self.AutoJoin.show()
         self.AutoJoin.connect("toggled", self.OnAutojoin)
@@ -737,6 +804,9 @@ class ChatRoomTab:
         if create:
             self.ChatRoomTab.add(self.Main)
 
+    def OnTickerClicked(self, widget):
+        pass
+
     def OnEnter(self, widget):
         pass
 
@@ -809,6 +879,7 @@ class PrivateChatTab:
         self.hbox5.pack_start(self.Encoding, gtk.FALSE, gtk.FALSE, 0)
 
         self.Log = gtk.CheckButton()
+        self.Log.set_active(gtk.FALSE)
         self.Log.set_label(_("Log"))
         self.Log.show()
         self.Log.connect("toggled", self.OnLogToggled)
@@ -868,6 +939,7 @@ class SearchTab:
         self.hbox6.set_spacing(5)
 
         self.checkbutton1 = gtk.CheckButton()
+        self.checkbutton1.set_active(gtk.FALSE)
         self.checkbutton1.set_label(_("Enable filters"))
         self.checkbutton1.show()
         self.checkbutton1.connect("toggled", self.OnToggleFilters)
@@ -888,6 +960,7 @@ class SearchTab:
         self.hbox6.pack_start(self.button3, gtk.FALSE, gtk.FALSE, 0)
 
         self.RememberCheckButton = gtk.CheckButton()
+        self.RememberCheckButton.set_active(gtk.FALSE)
         self.RememberCheckButton.set_label(_("Remember"))
         self.RememberCheckButton.show()
         self.RememberCheckButton.connect("toggled", self.OnToggleRemember)
@@ -956,7 +1029,7 @@ class SearchTab:
 
         self.Filters.pack_start(self.FilterSize, gtk.FALSE, gtk.TRUE, 0)
 
-        self.label16 = gtk.Label(_("Bitrate"))
+        self.label16 = gtk.Label(_("Bitrate:"))
         self.label16.set_padding(0, 0)
         self.label16.show()
         self.Filters.pack_start(self.label16, gtk.FALSE, gtk.FALSE, 0)
@@ -976,7 +1049,28 @@ class SearchTab:
 
         self.Filters.pack_start(self.FilterBitrate, gtk.FALSE, gtk.TRUE, 0)
 
+        self.label23 = gtk.Label(_("Country:"))
+        self.label23.set_padding(0, 0)
+        self.label23.show()
+        self.Filters.pack_start(self.label23, gtk.FALSE, gtk.FALSE, 0)
+
+        self.FilterCountry = gtk.Combo()
+        self.FilterCountry.set_size_request(75, -1)
+        self.FilterCountry.show()
+
+        self.combo_entry5 = self.FilterCountry.entry
+        self.combo_entry5.set_text("")
+        self.combo_entry5.set_editable(gtk.TRUE)
+        self.combo_entry5.show()
+        self.combo_entry5.connect("activate", self.OnRefilter)
+
+        self.combo_list6 = self.FilterCountry.list
+        self.combo_list6.show()
+
+        self.Filters.pack_start(self.FilterCountry, gtk.FALSE, gtk.TRUE, 0)
+
         self.FilterFreeSlot = gtk.CheckButton()
+        self.FilterFreeSlot.set_active(gtk.FALSE)
         self.FilterFreeSlot.set_label(_("Free slot"))
         self.FilterFreeSlot.show()
         self.FilterFreeSlot.connect("toggled", self.OnRefilter)
@@ -1045,37 +1139,31 @@ class UserInfoTab:
         self.frame1.show()
         self.frame1.set_shadow_type(gtk.SHADOW_ETCHED_IN)
 
-        self.scrolledwindow18 = gtk.ScrolledWindow()
-        self.scrolledwindow18.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-        self.scrolledwindow18.show()
-        self.scrolledwindow18.set_shadow_type(gtk.SHADOW_IN)
-
-        self.viewport3 = gtk.Viewport()
-        self.viewport3.show()
-        self.viewport3.set_shadow_type(gtk.SHADOW_IN)
-
-        self.vbox11 = gtk.VBox(gtk.FALSE, 0)
-        self.vbox11.show()
-        self.vbox11.set_spacing(0)
+        self.vbox16 = gtk.VBox(gtk.FALSE, 0)
+        self.vbox16.show()
+        self.vbox16.set_spacing(0)
 
         self.Encoding = gtk.OptionMenu()
         self.Encoding.show()
         self.Encoding.connect("changed", self.OnEncodingChanged)
 
-        self.vbox11.pack_start(self.Encoding, gtk.FALSE, gtk.FALSE, 0)
+        self.vbox16.pack_start(self.Encoding, gtk.FALSE, gtk.FALSE, 0)
+
+        self.scrolledwindow28 = gtk.ScrolledWindow()
+        self.scrolledwindow28.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+        self.scrolledwindow28.show()
+        self.scrolledwindow28.set_shadow_type(gtk.SHADOW_IN)
 
         self.descr = gtk.TextView()
         self.descr.set_wrap_mode(gtk.WRAP_WORD)
         self.descr.set_cursor_visible(gtk.FALSE)
         self.descr.set_editable(gtk.FALSE)
         self.descr.show()
-        self.vbox11.pack_start(self.descr, gtk.TRUE, gtk.TRUE, 0)
+        self.scrolledwindow28.add(self.descr)
 
-        self.viewport3.add(self.vbox11)
+        self.vbox16.pack_start(self.scrolledwindow28, gtk.TRUE, gtk.TRUE, 0)
 
-        self.scrolledwindow18.add(self.viewport3)
-
-        self.frame1.add(self.scrolledwindow18)
+        self.frame1.add(self.vbox16)
 
         self.label17 = gtk.Label(_("Self description:"))
         self.label17.set_padding(0, 0)
