@@ -1,4 +1,4 @@
-# Copyright (c) 2003 Hyriand. All rights reserved.
+# Copyright (c) 2003-2004 Hyriand. All rights reserved.
 #
 import gtk
 import gobject
@@ -135,15 +135,15 @@ class Searches:
 		self.searches[id] = search
 		return search
 		
-	def ShowResult(self, msg, username):
+	def ShowResult(self, msg, username, country):
 		if not self.searches.has_key(msg.token):
 			return
-
+		
 		search = self.searches[msg.token]
 		if search[2] == None:
 			search = self.CreateTab(search[0], search[1], search[3], search[4])
 		
-		search[2].AddResult(msg, username)
+		search[2].AddResult(msg, username, country)
 
 	def RemoveAutoSearch(self, id):
 		if not id in self.searches:
@@ -174,10 +174,10 @@ class Searches:
 		i[4] = 1
 	
 class SearchTreeModel(FastListModel):
-	COLUMNS = 13
+	COLUMNS = 14
 	COLUMN_TYPES = [gobject.TYPE_INT, gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING,
     			gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING,
-    			gobject.TYPE_INT, gobject.TYPE_STRING, gobject.TYPE_INT, gobject.TYPE_INT, gobject.TYPE_INT]
+    			gobject.TYPE_INT, gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_INT, gobject.TYPE_INT, gobject.TYPE_INT]
 
 	def __init__(self):
 		FastListModel.__init__(self)
@@ -214,11 +214,11 @@ class SearchTreeModel(FastListModel):
 		col = self.sort_col
 		order = self.sort_order
 		if col == 3:
-			col = 12
-		elif col == 4:
 			col = 13
-		elif col == 5:
+		elif col == 4:
 			col = 14
+		elif col == 5:
+			col = 15
 
 		if self.COLUMN_TYPES[col] == gobject.TYPE_STRING:
 			compare = locale.strcoll
@@ -271,20 +271,29 @@ class SearchTreeModel(FastListModel):
 			return gtk.FALSE
 		if filters[1] and filters[1].search(row[1].lower()):
 			return gtk.FALSE
-		if filters[2] and not self.checkDigit(filters[2], row[12]):
+		if filters[2] and not self.checkDigit(filters[2], row[13]):
 			return gtk.FALSE
 		if filters[3] and not self.checkDigit(filters[3], row[10], gtk.FALSE):
 			return gtk.FALSE
 		if filters[4] and row[6] != "Y":
 			return gtk.FALSE
+		if filters[5]:
+			for cc in filters[5]:
+				if not cc:
+					continue
+				if cc[0] == "-":
+					if row[12] == cc[1:]:
+						return gtk.FALSE
+				elif cc != row[12]:
+					return gtk.FALSE
 		return gtk.TRUE
 	
-	def set_filters(self, enable, f_in, f_out, size, bitrate, freeslot):
+	def set_filters(self, enable, f_in, f_out, size, bitrate, freeslot, country):
 		if not enable:
 			self.filters = None
 			self.data = self.all_data[:]
 			return
-		self.filters = [None, None, None, None, freeslot]
+		self.filters = [None, None, None, None, freeslot, None]
 		
 		if f_in:
 			try:
@@ -306,6 +315,9 @@ class SearchTreeModel(FastListModel):
 		if bitrate:
 			self.filters[3] = bitrate
 
+		if country:
+			self.filters[5] = country.upper().split(" ")
+
 		self.data = []
 		for row in self.all_data:
 			if self.check_filter(row):
@@ -331,6 +343,7 @@ class Search(SearchTab):
 		self.FilterOut.disable_activate()
 		self.FilterSize.disable_activate()
 		self.FilterBitrate.disable_activate()
+		self.FilterCountry.disable_activate()
 
 		if self.frame.np.config.sections["searches"]["enablefilters"]:
 			filter = self.frame.np.config.sections["searches"]["defilter"]
@@ -339,6 +352,8 @@ class Search(SearchTab):
 			self.FilterSize.entry.set_text(filter[2])
 			self.FilterBitrate.entry.set_text(filter[3])
 			self.FilterFreeSlot.set_active(filter[4])
+			if(len(filter) > 5):
+				self.FilterCountry.entry.set_text(filter[5])
 			self.checkbutton1.set_active(1)
 
 		if mode > 0:
@@ -390,7 +405,7 @@ class Search(SearchTab):
 			("$" + _("Ignore this user"), popup.OnIgnoreUser),
 		)
 		
-		self.ResultsList.connect("button_press_event", self.OnPopupMenu)
+		self.ResultsList.connect("button_press_event", self.OnListClicked)
 		
 		self._more_results = 0
 		self.new_results = []
@@ -403,6 +418,18 @@ class Search(SearchTab):
 		
 		if not user in self.selected_users:
 			self.selected_users.append(user)
+	
+	def OnListClicked(self, widget, event):
+		if event.button == 1 and event.type == gtk.gdk._2BUTTON_PRESS:
+			self.selected_results = []
+			self.selected_users = []
+			self.ResultsList.get_selection().selected_foreach(self.SelectedResultsCallback)
+			self.OnDownloadFiles(widget)
+			self.ResultsList.get_selection().unselect_all();
+			return gtk.TRUE
+		elif event.button == 3:
+			return self.OnPopupMenu(widget, event)
+		return gtk.FALSE
 		
 	def OnPopupMenu(self, widget, event):
 		if event.button != 3:
@@ -441,7 +468,7 @@ class Search(SearchTab):
 		self.popup_menu.popup(None, None, None, event.button, event.time)
 		return gtk.TRUE
 		
-	def AddResult(self, msg, user):
+	def AddResult(self, msg, user, country):
 		if user in self.users:
 			return
 		self.users.append(user)
@@ -466,7 +493,7 @@ class Search(SearchTab):
 				bitrate = str(a[0]) + bitrate
 				br = a[0]
 				length = '%i:%02i' %(a[1] / 60, a[1] % 60)
-			results.append([decode(name), user, result[2], msg.ulspeed, msg.inqueue, imdl, bitrate, length, decode(dir), br, result[1]])
+			results.append([decode(name), user, result[2], msg.ulspeed, msg.inqueue, imdl, bitrate, length, decode(dir), br, result[1], country])
 			ix += 1
 			
 		if results:
@@ -484,7 +511,7 @@ class Search(SearchTab):
 			self._more_results = 1
 			return gtk.TRUE
 		
-		r = self.new_results[:]
+		r = self.new_results
 		self.new_results = []
 		self._more_results = 0
 
@@ -544,7 +571,7 @@ class Search(SearchTab):
 		else:
 			self.Filters.hide()
 			self.ResultsList.set_model(None)
-			self.resultsmodel.set_filters(0, None, None, None, None, None)
+			self.resultsmodel.set_filters(0, None, None, None, None, None, "")
 			self.ResultsList.set_model(self.resultsmodel)
 
 	def OnIgnore(self, widget):
@@ -587,9 +614,10 @@ class Search(SearchTab):
 		f_size = self.PushHistory(self.FilterSize, "filtersize")
 		f_br = self.PushHistory(self.FilterBitrate, "filterbr")
 		f_free = self.FilterFreeSlot.get_active()
+		f_country = self.PushHistory(self.FilterCountry, "filtercc")
 		
 		self.ResultsList.set_model(None)
-		self.resultsmodel.set_filters(1, f_in, f_out, f_size, f_br, f_free)
+		self.resultsmodel.set_filters(1, f_in, f_out, f_size, f_br, f_free, f_country)
 		self.ResultsList.set_model(self.resultsmodel)
 
 	def OnResort(self, column, column_id):
