@@ -145,6 +145,7 @@ class ServerFrame:
         self.vbox76.set_spacing(0)
 
         self.DirectConnection = gtk.CheckButton()
+        self.DirectConnection.set_active(gtk.FALSE)
         self.DirectConnection.set_label(_("I can receive direct connections"))
         self.DirectConnection.show()
         self.vbox76.pack_start(self.DirectConnection, gtk.FALSE, gtk.FALSE, 0)
@@ -327,6 +328,7 @@ class SharesFrame:
         self.vbox79.pack_start(self.hbox111, gtk.FALSE, gtk.FALSE, 0)
 
         self.ShareDownloadDir = gtk.CheckButton()
+        self.ShareDownloadDir.set_active(gtk.FALSE)
         self.ShareDownloadDir.set_label(_("Share download directory"))
         self.ShareDownloadDir.show()
         self.ShareDownloadDir.connect("toggled", self.OnShareDownloadDirToggled)
@@ -416,6 +418,7 @@ class SharesFrame:
         self.vbox77.pack_start(self.hbox113, gtk.TRUE, gtk.TRUE, 0)
 
         self.RescanOnStartup = gtk.CheckButton()
+        self.RescanOnStartup.set_active(gtk.FALSE)
         self.RescanOnStartup.set_label(_("Rescan shares on startup"))
         self.RescanOnStartup.show()
         self.vbox77.pack_start(self.RescanOnStartup, gtk.FALSE, gtk.FALSE, 0)
@@ -467,9 +470,9 @@ class TransfersFrame:
         self.Main.show()
         self.Main.set_shadow_type(gtk.SHADOW_ETCHED_IN)
 
-        self.vbox81 = gtk.VBox(gtk.FALSE, 10)
+        self.vbox81 = gtk.VBox(gtk.FALSE, 15)
         self.vbox81.show()
-        self.vbox81.set_spacing(10)
+        self.vbox81.set_spacing(15)
         self.vbox81.set_border_width(5)
 
         self.vbox82 = gtk.VBox(gtk.FALSE, 0)
@@ -510,6 +513,7 @@ class TransfersFrame:
         self.hbox118.set_spacing(5)
 
         self.QueueUseSlots = gtk.CheckButton()
+        self.QueueUseSlots.set_active(gtk.FALSE)
         self.QueueUseSlots.set_label(_("Number of uploads exceeds"))
         self.QueueUseSlots.show()
         self.QueueUseSlots.connect("toggled", self.OnQueueUseSlotsToggled)
@@ -549,18 +553,21 @@ class TransfersFrame:
         self.table1.attach(self.label188, 2, 3, 0, 1, 0, 0, 0, 0)
 
         self.Limit = gtk.CheckButton()
+        self.Limit.set_active(gtk.FALSE)
         self.Limit.set_label(_("Limit uploads speed to"))
         self.Limit.show()
         self.Limit.connect("toggled", self.OnLimitToggled)
         self.table1.attach(self.Limit, 0, 1, 0, 1, 0, 0, 0, 0)
 
         self.LimitPerTransfer = gtk.RadioButton()
+        self.LimitPerTransfer.set_active(gtk.FALSE)
         self.LimitPerTransfer.set_label(_("per transfer"))
         self.LimitPerTransfer.show()
 
         self.table1.attach(self.LimitPerTransfer, 3, 4, 0, 1, gtk.FILL, 0, 0, 0)
 
         self.LimitTotalTransfers = gtk.RadioButton(self.LimitPerTransfer)
+        self.LimitTotalTransfers.set_active(gtk.FALSE)
         self.LimitTotalTransfers.set_label(_("total transfers"))
         self.LimitTotalTransfers.show()
 
@@ -597,6 +604,7 @@ class TransfersFrame:
         self.vbox83.pack_start(self.hbox119, gtk.FALSE, gtk.FALSE, 0)
 
         self.FriendsNoLimits = gtk.CheckButton()
+        self.FriendsNoLimits.set_active(gtk.FALSE)
         self.FriendsNoLimits.set_label(_("Queue limit does not apply to friends"))
         self.FriendsNoLimits.show()
         self.vbox83.pack_start(self.FriendsNoLimits, gtk.FALSE, gtk.FALSE, 0)
@@ -604,16 +612,24 @@ class TransfersFrame:
         self.vbox81.pack_start(self.vbox83, gtk.FALSE, gtk.FALSE, 0)
 
         self.FriendsOnly = gtk.CheckButton()
+        self.FriendsOnly.set_active(gtk.FALSE)
         self.FriendsOnly.set_label(_("Share to friends only"))
         self.FriendsOnly.show()
         self.FriendsOnly.connect("toggled", self.OnFriendsOnlyToggled)
         self.vbox81.pack_start(self.FriendsOnly, gtk.FALSE, gtk.FALSE, 0)
 
         self.PreferFriends = gtk.CheckButton()
+        self.PreferFriends.set_active(gtk.FALSE)
         self.PreferFriends.set_label(_("Privilege all my friends"))
         self.PreferFriends.show()
         self.vbox81.pack_start(self.PreferFriends, gtk.FALSE, gtk.FALSE, 0)
 
+        self.LockIncoming = gtk.CheckButton()
+        self.LockIncoming.set_active(gtk.FALSE)
+        self.LockIncoming.set_label(_("Lock incoming files (turn off for NFS)"))
+        self.LockIncoming.show()
+        self.vbox81.pack_start(self.LockIncoming, gtk.FALSE, gtk.FALSE, 0)
+
         self.Main.add(self.vbox81)
 
         self.label183 = gtk.Label(_("Transfers"))
@@ -774,6 +790,12 @@ class BloatFrame:
         self.vbox86.set_spacing(10)
         self.vbox86.set_border_width(5)
 
+        self.TabClosers = gtk.CheckButton()
+        self.TabClosers.set_active(gtk.FALSE)
+        self.TabClosers.set_label(_("Close-buttons on tabs (requires restart)"))
+        self.TabClosers.show()
+        self.vbox86.pack_start(self.TabClosers, gtk.FALSE, gtk.FALSE, 0)
+
         self.table2 = gtk.Table()
         self.table2.show()
         self.table2.set_row_spacings(0)
@@ -1223,15 +1245,23 @@ class LogFrame:
         self.vbox89.set_border_width(5)
 
         self.LogPrivate = gtk.CheckButton()
+        self.LogPrivate.set_active(gtk.FALSE)
         self.LogPrivate.set_label(_("Log private chat by default"))
         self.LogPrivate.show()
         self.vbox89.pack_start(self.LogPrivate, gtk.FALSE, gtk.FALSE, 0)
 
         self.LogRooms = gtk.CheckButton()
+        self.LogRooms.set_active(gtk.FALSE)
         self.LogRooms.set_label(_("Log chatrooms by default"))
         self.LogRooms.show()
         self.vbox89.pack_start(self.LogRooms, gtk.FALSE, gtk.FALSE, 0)
 
+        self.LogTransfers = gtk.CheckButton()
+        self.LogTransfers.set_active(gtk.FALSE)
+        self.LogTransfers.set_label(_("Log transfers"))
+        self.LogTransfers.show()
+        self.vbox89.pack_start(self.LogTransfers, gtk.FALSE, gtk.FALSE, 0)
+
         self.vbox90 = gtk.VBox(gtk.FALSE, 0)
         self.vbox90.show()
         self.vbox90.set_spacing(0)
@@ -1551,6 +1581,7 @@ class BanFrame:
         self.hbox146.set_spacing(0)
 
         self.UseCustomBan = gtk.CheckButton()
+        self.UseCustomBan.set_active(gtk.FALSE)
         self.UseCustomBan.set_label(_("Use custom ban message:"))
         self.UseCustomBan.show()
         self.UseCustomBan.connect("toggled", self.OnUseCustomBanToggled)
@@ -1646,11 +1677,13 @@ class SearchFrame:
         self.vbox93.pack_start(self.hbox147, gtk.FALSE, gtk.FALSE, 0)
 
         self.RegexpFilters = gtk.CheckButton()
+        self.RegexpFilters.set_active(gtk.FALSE)
         self.RegexpFilters.set_label(_("Use regular expressions for filter in & out"))
         self.RegexpFilters.show()
         self.vbox93.pack_start(self.RegexpFilters, gtk.FALSE, gtk.FALSE, 0)
 
         self.EnableFilters = gtk.CheckButton()
+        self.EnableFilters.set_active(gtk.FALSE)
         self.EnableFilters.set_label(_("Enable filters by default"))
         self.EnableFilters.show()
         self.EnableFilters.connect("toggled", self.OnEnableFiltersToggled)
@@ -1722,9 +1755,28 @@ class SearchFrame:
         self.table4.attach(self.hbox163, 1, 2, 3, 4, gtk.FILL, gtk.FILL, 0, 0)
 
         self.FilterFree = gtk.CheckButton()
+        self.FilterFree.set_active(gtk.FALSE)
         self.FilterFree.set_label(_("Free slot"))
         self.FilterFree.show()
-        self.table4.attach(self.FilterFree, 1, 2, 4, 5, gtk.FILL, 0, 0, 0)
+        self.table4.attach(self.FilterFree, 1, 2, 5, 6, gtk.FILL, 0, 0, 0)
+
+        self.label259 = gtk.Label(_("Country:"))
+        self.label259.set_alignment(0, 0.5)
+        self.label259.set_padding(0, 0)
+        self.label259.show()
+        self.table4.attach(self.label259, 0, 1, 4, 5, gtk.FILL, 0, 0, 0)
+
+        self.hbox164 = gtk.HBox(gtk.FALSE, 0)
+        self.hbox164.show()
+        self.hbox164.set_spacing(0)
+
+        self.FilterCC = gtk.Entry()
+        self.FilterCC.set_text("")
+        self.FilterCC.set_editable(gtk.TRUE)
+        self.FilterCC.show()
+        self.hbox164.pack_start(self.FilterCC, gtk.FALSE, gtk.TRUE, 0)
+
+        self.table4.attach(self.hbox164, 1, 2, 4, 5, gtk.FILL, gtk.FILL, 0, 0)
 
         self.vbox93.pack_start(self.table4, gtk.TRUE, gtk.TRUE, 0)
 
@@ -2016,12 +2068,14 @@ class GeoBlockFrame:
         self.vbox98.set_border_width(5)
 
         self.GeoBlock = gtk.CheckButton()
+        self.GeoBlock.set_active(gtk.FALSE)
         self.GeoBlock.set_label(_("Enable geographical blocker"))
         self.GeoBlock.show()
         self.GeoBlock.connect("toggled", self.OnGeoBlockToggled)
         self.vbox98.pack_start(self.GeoBlock, gtk.FALSE, gtk.FALSE, 0)
 
         self.GeoPanic = gtk.CheckButton()
+        self.GeoPanic.set_active(gtk.FALSE)
         self.GeoPanic.set_label(_("Geographical paranoia (block unresolvable IPs)"))
         self.GeoPanic.show()
         self.vbox98.pack_start(self.GeoPanic, gtk.FALSE, gtk.FALSE, 0)
@@ -2079,12 +2133,14 @@ class UrlCatchFrame:
         self.vbox99.set_border_width(5)
 
         self.URLCatching = gtk.CheckButton()
+        self.URLCatching.set_active(gtk.FALSE)
         self.URLCatching.set_label(_("Enable URL catching"))
         self.URLCatching.show()
         self.URLCatching.connect("toggled", self.OnURLCatchingToggled)
         self.vbox99.pack_start(self.URLCatching, gtk.FALSE, gtk.FALSE, 0)
 
         self.HumanizeURLs = gtk.CheckButton()
+        self.HumanizeURLs.set_active(gtk.FALSE)
         self.HumanizeURLs.set_label(_("Humanize slsk:// urls"))
         self.HumanizeURLs.show()
         self.vbox99.pack_start(self.HumanizeURLs, gtk.FALSE, gtk.FALSE, 0)
