@@ -1,4 +1,4 @@
-# Copyright (c) 2003 Hyriand. All rights reserved.
+# Copyright (c) 2003-2004 Hyriand. All rights reserved.
 #
 # Based on code from PySoulSeek, original copyright note:
 # Copyright (c) 2001-2003 Alexander Kanavin. All rights reserved.
@@ -186,10 +186,10 @@ class Transfers:
 	    if i.user == user and i.filename == msg.file and (i.conn is not None or i.status in [_("Connection closed by peer"), _("Establishing connection")]):
 		self.AbortTransfer(i)
 		self.getFile(i.user, i.filename, i.path, i)
-		self.eventprocessor.logMessage(_("Retrying failed download: user %s, file %s") %(i.user,self.decode(i.filename)))
+		self.eventprocessor.logTransfer(_("Retrying failed download: user %s, file %s") %(i.user,self.decode(i.filename)), 1)
 		break
 	else:
-	    self.eventprocessor.logMessage(_("Failed download: user %s, file %s") %(user,self.decode(msg.file)))
+	    self.eventprocessor.logTransfer(_("Failed download: user %s, file %s") %(user,self.decode(msg.file)), 1)
 
     def gettingAddress(self, req):
 	for i in self.downloads:
@@ -529,14 +529,15 @@ class Transfers:
                     i.conn = None
                     self.queue.put(slskmessages.ConnClose(msg.conn))
 		  else:
-		    try:
-		      import fcntl
+                    if self.eventprocessor.config.sections["transfers"]["lock"]:
 		      try:
-		        fcntl.lockf(f, fcntl.LOCK_EX|fcntl.LOCK_NB)
-		      except IOError, strerror:
-			self.eventprocessor.logMessage(_("Can't get an exclusive lock on file - I/O error: %s") % strerror)
-		    except ImportError:
-		      pass
+		        import fcntl
+		        try:
+		          fcntl.lockf(f, fcntl.LOCK_EX|fcntl.LOCK_NB)
+		        except IOError, strerror:
+			  self.eventprocessor.logMessage(_("Can't get an exclusive lock on file - I/O error: %s") % strerror)
+		      except ImportError:
+		        pass
                     f.seek(0,2)
 		    size = f.tell()
 		    self.queue.put(slskmessages.DownloadFile(i.conn,size,f,i.size))
@@ -546,6 +547,7 @@ class Transfers:
 		    i.offset = size
 		    i.starttime = time.time()
 		    self.eventprocessor.logMessage(_("Download started: %s") % self.decode(f.name))
+		    self.eventprocessor.logTransfer(_("Download started: user %s, file %s") % (i.user, self.decode(i.filename)))
 
                 self.downloadspanel.update(i)
 		return
@@ -558,9 +560,10 @@ class Transfers:
                     i.transfertimer.cancel()
                 try:
 		    f = open(i.filename.replace("\\",os.sep),"rb")
-		    self.queue.put(slskmessages.UploadFile(i.conn,file = f,size =i.size))
+		    self.queue.put(slskmessages.UploadFile(i.conn,file = f,size = i.size))
 		    i.status = _("Initializing transfer")
 		    i.file = f
+		    self.eventprocessor.logTransfer(_("Upload started: user %s, file %s") % (i.user, self.decode(i.filename)))
                 except IOError, strerror:
 		    self.eventprocessor.logMessage(_("I/O error: %s") % strerror)
                     i.status = _("Local file error")
@@ -620,6 +623,7 @@ class Transfers:
 		                    self.eventprocessor.logMessage(_("Couldn't move '%s' to '%s'") % (self.decode(msg.file.name), self.decode(newname)))
 		            i.status = _("Finished")
 			    self.eventprocessor.logMessage(_("Download finished: %s") % self.decode(newname))
+			    self.eventprocessor.logTransfer(_("Download finished: user %s, file %s") % (i.user, self.decode(i.filename)))
 			    self.queue.put(slskmessages.ConnClose(msg.conn))
 			    if i.speed is not None:
 			        self.queue.put(slskmessages.SendSpeed(i.user, int(i.speed*1024)))
@@ -718,6 +722,7 @@ class Transfers:
 		    for j in self.uploads:
 			if j.user == i.user:
 			    j.timequeued = curtime
+		    self.eventprocessor.logTransfer(_("Upload finished: user %s, file %s") % (i.user, self.decode(i.filename)))
 		    self.checkUploadQueue()
 		    self.uploadspanel.update(i)
 		if needupdate:
@@ -775,9 +780,10 @@ class Transfers:
 	listpriv = {user:time.time()}
 	countogg = 0
 	countpriv = 0
+	
         for i in self.uploads:
 	    if i.status == "Queued":
-		if i.user in self.privilegedusers or self.UserListPrivileged(i.user):
+		if i.user in listpriv.keys() or i.user in self.privilegedusers or self.UserListPrivileged(i.user):
 		    listpriv[i.user] = i.timequeued
 		    countpriv += 1
 		elif i.filename[-4:].lower() == ".ogg":
@@ -896,7 +902,7 @@ class Transfers:
 		    else:
 		        i.status = _("Connection closed by peer")
 		        if i in self.downloads:
-			    self.eventprocessor.logMessage(_("Retrying failed download: user %s, file %s") %(i.user, self.decode(i.filename)))
+			    self.eventprocessor.logTransfer(_("Retrying failed download: user %s, file %s") %(i.user, self.decode(i.filename)), 1)
 			    self.getFile(i.user, i.filename, i.path, i)
 		i.conn = None
        	        self.downloadspanel.update(i)
@@ -977,7 +983,10 @@ class Transfers:
 	    	    os.remove(transfer.file.name)
 	    except:
 		pass
-
+	    if transfer in self.uploads:
+	        self.eventprocessor.logTransfer(_("Upload aborted, user %s file %s") % (transfer.user, transfer.filename))
+	    else:
+	        self.eventprocessor.logTransfer(_("Download aborted, user %s file %s") % (transfer.user, transfer.filename))
 
     def GetDownloads(self):
 	""" Get a list of incomplete and not aborted downloads """
@@ -999,7 +1008,7 @@ class Transfers:
             coding = self.eventprocessor.config.sections["server"]["userencoding"][user]
         s = self.eventprocessor.decode(s, coding)
         try:
-#            return s.encode(locale.nl_langinfo(locale.CODESET), "replace")
-            return s.sencode(os.filesystemencoding(), "replace")
+            return s.encode(locale.nl_langinfo(locale.CODESET), "replace")
+#            return s.sencode(os.filesystemencoding(), "replace")
         except:
             return s
